# Replication of "null results" - Absence of evidence or evidence of absence?

This repository contains code and data related to

Pawel, S., Heyard, R., Micheloud, C., Held, L. (2023). Replication of "null
results" - Absence of evidence or evidence of absence?

## Reproducibility

Our results can be reproduced in two ways

### 1. Reproducing the results locally


Make sure that R, and the R packages indicated in the `./CRANpackages.txt` file
are installed

```sh
## install packages from CRAN by running from a shell
R -e 'install.packages(read.delim("CRANpackages.txt", header = FALSE)[,1])'
```

To only rerun the R code without recompiling the manuscript use the file
`./paper/rsabsence.R`. To recompile the manuscript, make also sure that Make,
LaTeX and all necessary LaTeX packages (e.g., the texlive-full distribution on
Ubuntu) are installed. Then run

```
make local
```

this should produce `./rsabsence.pdf`.


Although the analyses depend on only few dependencies, this approach may lead to
different results (or not even compile successfully) in the future if R or the
packages change. The R and R package versions which were used when the paper was
successfully compiled before submission are visible in the following output

```r
sessionInfo()

#> R version 4.3.0 (2023-04-21)
#> Platform: x86_64-pc-linux-gnu (64-bit)
#> Running under: Ubuntu 20.04.6 LTS
#> 
#> Matrix products: default
#> BLAS:   /usr/lib/x86_64-linux-gnu/blas/libblas.so.3.9.0 
#> LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.9.0
#> 
#> locale:
#>  [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
#>  [3] LC_TIME=de_CH.UTF-8        LC_COLLATE=en_US.UTF-8    
#>  [5] LC_MONETARY=de_CH.UTF-8    LC_MESSAGES=en_US.UTF-8   
#>  [7] LC_PAPER=de_CH.UTF-8       LC_NAME=C                 
#>  [9] LC_ADDRESS=C               LC_TELEPHONE=C            
#> [11] LC_MEASUREMENT=de_CH.UTF-8 LC_IDENTIFICATION=C       
#> 
#> time zone: Europe/Zurich
#> tzcode source: system (glibc)
#> 
#> attached base packages:
#> [1] stats     graphics  grDevices utils     datasets  methods   base     
#> 
#> other attached packages:
#> [1] reporttools_1.1.3 xtable_1.8-4      dplyr_1.1.2       gridExtra_2.3    
#> [5] ggplot2_3.4.2     knitr_1.42       
#> 
#> loaded via a namespace (and not attached):
#>  [1] vctrs_0.6.2       cli_3.6.1         rlang_1.1.0       xfun_0.39        
#>  [5] generics_0.1.3    labeling_0.4.2    glue_1.6.2        colorspace_2.1-0 
#>  [9] scales_1.2.1      fansi_1.0.4       grid_4.3.0        munsell_0.5.0    
#> [13] tibble_3.2.1      lifecycle_1.0.3   compiler_4.3.0    pkgconfig_2.0.3  
#> [17] farver_2.1.1      viridisLite_0.4.1 R6_2.5.1          tidyselect_1.2.0 
#> [21] utf8_1.2.3        pillar_1.9.0      magrittr_2.0.3    tools_4.3.0      
#> [25] withr_2.5.0       gtable_0.3.3

cat(paste(Sys.time(), Sys.timezone(), "\n"))

#> 2023-05-08 09:19:12.440643 Europe/Zurich  
```

### 2. Reproducing the results within a Docker container

Make sure that Make, LaTeX with all necessary packages (e.g., the texlive-full
distribution on Ubuntu), and Docker with root rights are installed. Then run

```
make docker
```

The Docker approach reruns the analyses in a Docker container which encapsulates
the computational environment (R and R package versions) that was used in the
original analysis. The only way this approach could become non-reproducible is
when the [rocker/verse](https://hub.docker.com/r/rocker/verse/tags) base image
becomes unavailable and/or the Posit Public Package Manager (RStudio Package
Manager, RSPM) snapshot of CRAN becomes unavailable.
